http

package
v0.0.0-...-7b65136 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 23, 2020 License: MIT Imports: 15 Imported by: 0

Documentation

Overview

Package http provides an HTTP client for the LogService service.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CtxValuesToSend

func CtxValuesToSend(keys ...string) httptransport.ClientOption

CtxValuesToSend configures the http client to pull the specified keys out of the context and add them to the http request as headers. Note that keys will have net/http.CanonicalHeaderKey called on them before being send over the wire and that is the form they will be available in the server context.

func DecodeHTTPPingResponse

func DecodeHTTPPingResponse(_ context.Context, r *http.Response) (interface{}, error)

DecodeHTTPPingResponse is a transport/http.DecodeResponseFunc that decodes a JSON-encoded Response response from the HTTP response body. If the response has a non-200 status code, we will interpret that as an error and attempt to decode the specific error message from the response body. Primarily useful in a client.

func DecodeHTTPSubmitMultipleResponse

func DecodeHTTPSubmitMultipleResponse(_ context.Context, r *http.Response) (interface{}, error)

DecodeHTTPSubmitMultipleResponse is a transport/http.DecodeResponseFunc that decodes a JSON-encoded Response response from the HTTP response body. If the response has a non-200 status code, we will interpret that as an error and attempt to decode the specific error message from the response body. Primarily useful in a client.

func DecodeHTTPSubmitSingleResponse

func DecodeHTTPSubmitSingleResponse(_ context.Context, r *http.Response) (interface{}, error)

DecodeHTTPSubmitSingleResponse is a transport/http.DecodeResponseFunc that decodes a JSON-encoded Response response from the HTTP response body. If the response has a non-200 status code, we will interpret that as an error and attempt to decode the specific error message from the response body. Primarily useful in a client.

func EncodeHTTPPingZeroRequest

func EncodeHTTPPingZeroRequest(_ context.Context, r *http.Request, request interface{}) error

EncodeHTTPPingZeroRequest is a transport/http.EncodeRequestFunc that encodes a ping request into the various portions of the http request (path, query, and body).

func EncodeHTTPSubmitMultipleZeroRequest

func EncodeHTTPSubmitMultipleZeroRequest(_ context.Context, r *http.Request, request interface{}) error

EncodeHTTPSubmitMultipleZeroRequest is a transport/http.EncodeRequestFunc that encodes a submitmultiple request into the various portions of the http request (path, query, and body).

func EncodeHTTPSubmitSingleZeroRequest

func EncodeHTTPSubmitSingleZeroRequest(_ context.Context, r *http.Request, request interface{}) error

EncodeHTTPSubmitSingleZeroRequest is a transport/http.EncodeRequestFunc that encodes a submitsingle request into the various portions of the http request (path, query, and body).

func New

func New(instance string, options ...httptransport.ClientOption) (pb.LogServiceServer, error)

New returns a service backed by an HTTP server living at the remote instance. We expect instance to come from a service discovery system, so likely of the form "host:port".

Types

This section is empty.

Jump to